#!/bin/bash

# Declare functions
	# Check return code from command
	errorCheckExit ()
	{
	if [ $? -ne 0 ]; then
		echo $1
		exit 1
	fi
	}

	errorCheckCont ()
	{
	if [ $? -ne 0 ]; then
		echo $1
	fi
	}

# Check we are running as root
if [[ $EUID -ne 0 ]]; then
	echo "This script must be run as root" 1>&2
	exit 1
fi

clear

# Display copyright notice
echo "#"
echo "# Copyright (C) 2013 Sophos Ltd, Oxford, England."
echo "# All rights reserved."
echo "#"
echo ""
echo ""

#Display the available network connections

echo "<<<<<Displaying available network locations>>>>>"
echo ""
networksetup -listnetworkserviceorder

read -p 'Enter Device Name used to connect to the Internet (eg: en0) : ' netin
echo ""
ifconfig $netin | grep -i -e 'inet' -e 'status: active' && ok=1 || ok=2
if [ $ok -eq 2 ]; then
	echo ""
	echo "<<<<<No Internet connection. Check specified Device and run the script again>>>>>"
	exit 1
else
	echo ""
	echo "<<<<<Confirmed Internet connection>>>>>"
	echo ""
fi

# Check for the existance of asl.conf
if [ ! -f /etc/asl.conf ]; then
	echo "/etc/asl.conf is missing!  Unable to continue."
	exit 1
else
	echo "/etc/asl.conf present"

#Create storage directory
echo "Creating temporary working directory…"
cd /tmp
mkdir -p trace/

# Backup asl.conf
cp /etc/asl.conf /etc/asl.conf.backup
errorCheckExit "Unable to backup /etc/asl.conf"

# Modify the config to store debug messages
echo "Modifying config"
sed 's/Level notice] store/Level debug] store/' /etc/asl.conf  > /etc/asl.conf.new 
	errorCheckExit "Unable to modify /etc/asl.conf"
	if [ ! -f /etc/asl.conf.new ]; then
		echo "/etc/asl.conf.new not present - unable to be written"
		exit 1
	fi
mv -f /etc/asl.conf /etc/asl.conf.orig
	errorCheckExit "Unable to move /etc/asl.conf to /etc/asl.conf.orig"
mv -f /etc/asl.conf.new /etc/asl.conf
	errorCheckExit "Unable to move /etc/asl.conf.new to /etc/asl.conf"

# Enable debug logging
echo "Enabling debug logging"
syslog -c `ps aux | grep SophosWebIntelligence | grep -v grep | awk '{print $2}'` d > /dev/null 2>&1
errorCheckExit "SophosWebIntelligence process not found, unable to set syslog to debug"

# Recreate issue
echo ""
echo "Please recreate the issue and once done press 'Ctrl+C' to continue"

stty flusho; tcpdump -i $netin -s 0 -B 524288 -w /tmp/trace/update.pcap ; stty -flusho

# Collect the trace logging
echo "Collecting trace logging"
syslog -k Sender SophosWebIntelligence > /tmp/trace/WebDNorm.out
	errorCheckCont "syslog -k command for SophosWebIntelligence failed"
syslog -F raw -k Sender SophosWebIntelligence > /tmp/trace/WebDRaw.out
	errorCheckCont "syslog -F raw -k command for SophosWebIntelligence failed"

# Disable debug logging
echo "Disabling debug logging"
syslog -c `ps aux | grep SophosWebIntelligence | grep -v grep | awk '{print $2}'` o
errorCheckCont "Unable to remove debug from SophosWebIntelligence in syslog"

# Reverting the config changes
echo "Reverting config"
mv -f /etc/asl.conf /etc/asl.conf.mod
	errorCheckCont "Unable to move /etc/asl.conf to /etc/asl.conf.mod"
mv -f /etc/asl.conf.orig /etc/asl.conf
	errorCheckCont "Unable to move /etc/asl.conf.orig to /etc/asl.conf"
rm -f /etc/asl.conf.mod
	errorCheckCont "Unable to remove /etc/asl.conf.mod"
	
# Remove asl.conf backup
rm -f /etc/asl.conf.backup
errorCheckCont "Unable to remove /etc/asl.conf.backup"

# Create trace log file archive
cd /tmp/
echo "Creating archive of files"
tar cjvf ~/Desktop/Sophos_Trace.tgz /tmp/trace > /dev/null 2>&1

# Remove storage directory

rm -rf /tmp/trace/*
rmdir /tmp/trace

# Advise script complete

echo ""
echo "Process complete. Please submit file 'Sophos_Trace.tgz' located on the Desktop."
echo ""

fi
